==> api-service-common-0.12.28.tgz: package/src/middleware/decrypt.ts <==
/*************************************************************************
 *
 * Troven CONFIDENTIAL
 * __________________
 *
 *  (c) 2017-2020 Troven Pty Ltd
 *  All Rights Reserved.
 *
 * NOTICE:  All information contained herein is, and remains
 * the property of Troven Pty Ltd and its licensors,
 * if any.  The intellectual and technical concepts contained
 * herein are proprietary to Troven Pty Ltd
 * and its suppliers and may be covered by International and Regional Patents,
 * patents in process, and are protected by trade secret or copyright law.
 * Dissemination of this information or reproduction of this material
 * is strictly forbidden unless prior written permission is obtained
 * from Troven Pty Ltd.
 */

import * as assert from "assert";
import * as _ from "lodash";
import * as CryptoJS from "crypto-js";
import {IOperation, IChassisContext, IChassisMiddleware} from "api-service-core";

/**
 * Decrypt Fields
 * --------------
 * Decrypt one or more fields using the shared secret
 *
 * @type {{name: string, title: string, when: [string,string], fn: module.exports.fn, Decrypter: module.exports.Decrypter}}
 */
export default class decrypt implements IChassisMiddleware {

    name = "api.decrypt";
    title = "Return payload with specified fields decrypted";

    fn(operation: IOperation, _options: any): Function {
        let context: IChassisContext = operation.context;

        assert(context, "missing context");

        let options = _.extend({ algo: "AES", secret: "", cipherField: "_encrypted_" }, _options, operation.feature);
        let cipher = CryptoJS[options.algo];
        assert(cipher, "missing cipher: "+options.algo);

        return function (req, res, next) {
            assert( req && res && next, "invalid middleware");
            let model = req.body;

            let cooked = model[options.cipherField];
            if (cooked) {
                let raw = cipher.decrypt( cooked, options.secret );
                var decryped = JSON.parse(raw.toString(CryptoJS.enc.Utf8));
                _.extend(model, decryped);
                delete model[options.cipherField];
    
                // req.body = req.json = model;
                // res.model = res.json = model;
                res.send(model);
                // next();
            } else {
                next();
            }

        };
    };
}

==> api-service-common-0.16.13.tgz: package/src/middleware/decrypt.ts <==
/*************************************************************************
 *
 * Troven CONFIDENTIAL
 * __________________
 *
 *  (c) 2017-2020 Troven Pty Ltd
 *  All Rights Reserved.
 *
 * NOTICE:  All information contained herein is, and remains
 * the property of Troven Pty Ltd and its licensors,
 * if any.  The intellectual and technical concepts contained
 * herein are proprietary to Troven Pty Ltd
 * and its suppliers and may be covered by International and Regional Patents,
 * patents in process, and are protected by trade secret or copyright law.
 * Dissemination of this information or reproduction of this material
 * is strictly forbidden unless prior written permission is obtained
 * from Troven Pty Ltd.
 */

import * as assert from "assert";
import * as _ from "lodash";
import * as CryptoJS from "crypto-js";
import {IOperation, IChassisContext, IChassisMiddleware} from "api-service-core";

/**
 * Decrypt Fields
 * --------------
 * Decrypt one or more fields using the shared secret
 *
 * @type {{name: string, title: string, when: [string,string], fn: module.exports.fn, Decrypter: module.exports.Decrypter}}
 */
export default class decrypt implements IChassisMiddleware {

    name = "api.decrypt";
    title = "Return payload with specified fields decrypted";

    fn(operation: IOperation, _options: any): Function {
        let context: IChassisContext = operation.context;

        assert(context, "missing context");

        let options = _.extend({ algo: "AES", secret: "", cipherField: "_encrypted_" }, _options);
        let cipher = CryptoJS[options.algo];
        assert(cipher, "missing cipher: "+options.algo);

        return function (req, res, next) {
            assert( req && res && next, "invalid middleware");
            let model = req.body;

            let cooked = model[options.cipherField];
            if (cooked) {
                let raw = cipher.decrypt( cooked, options.secret );
                var decryped = JSON.parse(raw.toString(CryptoJS.enc.Utf8));
                _.extend(model, decryped);
                delete model[options.cipherField];
    
                // req.body = req.json = model;
                // res.model = res.json = model;
                res.send(model);
                // next();
            } else {
                next();
            }

        };
    };
}
